@@ -13,18 +13,18 @@ test_that("parsnip + earth + axe_() works", {
     fit(Volume ~ ., data = trees)
   # Butcher
   x <- axe_call(earth_fit)
-  expect_equal(x$call, rlang::expr(dummy_call()))
+  expect_equal(x$fit$call, rlang::expr(dummy_call()))
   expect_error(update(x))
   x <- axe_fitted(earth_fit)
-  expect_equal(x$residuals, numeric(0))
+  expect_equal(x$fit$residuals, numeric(0))
   x <- axe_data(earth_fit)
-  expect_equal(x$x, data.frame(NA))
-  expect_equal(x$y, numeric(0))
-  expect_equal(residuals(x), residuals(earth_fit$fit))
+  # parsnip uses the formula interface for earth (#157)
+  expect_equal(x$fit$data, data.frame(NA))
+  expect_equal(residuals(x$fit), residuals(earth_fit$fit))
   x <- butcher(earth_fit)
-  expect_equal(format(x), format(earth_fit$fit))
+  expect_equal(format(x$fit), format(earth_fit$fit))
   # Predict
-  expected_output <- predict(earth_fit$fit, trees[1:3,])
+  expected_output <- predict(earth_fit, trees[1:3,])
   new_output <- predict(x, trees[1:3,])
   expect_equal(new_output, expected_output)
 })
